<?php
/* LuxCal display1  2009-2018 LuxSoft www.LuxSoft.eu*/$LDV='2016-11-22';
/*----------------------------- MUST READ -------------------------------
This file is part of the LuxCal Calendar and is distrubuted WITHOUT ANY 
WARRANTY. See the GNU General Public License for details.

This LuxCal display is best viewed in an iframe with a reduced width.

This display must be run from the calendar's root directory!

----------- The following settings / colors can be edited ------------
------ only edit the part on the right side of the equal sign ------*/

//GENERAL SETTINGS
$calID = "mycal"; //calendar to use (between the quotes: specify the ID of the calendar. Blank (""): the default calendar) 
$evtBody = '12345'; //on hover pop-up event fields (list of numbers: 1: venue, 2: category, 3: description, . . . for more see Settings page - Event templates)
$evtWin = 1; //on click open event window (0: no, 1: yes). If the user has post rights, the event add/edit window will open, otherwise the event report window will open
$wkDays = 1; //days of the week (0: work week, 1: full week)
$ef2Jump = 1; //if URL found in extra field 2, onclick open link in new window (0: disabled, 1: enabled)

//FILTERS
$groups = "0"; //events in groups to show (comma separated list of group IDs; 0: all groups)
$users = "0"; //events of users to show (comma separated list of user IDs; 0: all users)
$cats = "0"; //events in categories to show (comma separated list of cat IDs; 0: all categories)
$venue = ""; //case-insensitive text string to be present in venue. Blank (""): no filter 

//BACKGROUND COLORS - GENERAL
$BXXXX = "#A0B0C0"; //background body
$BBHAR = "#8090A6"; //bars, lines and headers
$BGCTH = "#C0D0F0"; //hover background day cell top

//BACKGROUND COLORS - GRID
$BGWD1 = "#FFFFEE"; //grid - weekday
$BGWE1 = "#FFFFCC"; //grid - weekend
$BGOUT = "#FEFEFE"; //grid - outside month
$BGTOD = "#EEEEFF"; //day cell today

//BACKGROUND COLORS - BOXES AND CELLS
$BHNOR = "#FFFFE0;"; //hover box normal event
$BHPRI = "#CCFFCC;"; //hover box private event
$BHREP = "#FFFFE0;"; //hover box repeating event

//FONT DEFINITIONS
$FFXXX = "12px arial, sans-serif"; //base font
$MDTHD = "1.0em"; //date header
$MBUTS = "1.0em"; //buttons
$MPOPU = "1.0em"; //hover popup box
$MSMAL = "0.8em"; //small text

//TEXT COLORS
$CXXXX = "#2B3856"; //normal text
$CBHAR = "#FFFFFF"; //text in headers
$CHLIT = "#FF2222"; //text highlight

//BORDER COLORS
$EXXXX = "#808080"; //general borders
$EHNOR = "#808080"; //hover box normal event
$EHPRI = "#808080"; //hover box private event
$EHREP = "#E00060"; //hover box repeating event
$EGTOD = "#0000FF"; //grid - day cell today

//SIZES (PIXELS)
$HDCEL = "50"; //daycell height
$HWDAY = "18"; //week days height
$SQUAR = "10"; //mini-squares

/*--------------------------------------------------------------------*/

function showEvents($date) {
	global $calID, $evtList, $evtBody, $evtWin;

	foreach ($evtList[$date] as &$evt) {
		$time = makeHovT($evt);
		$chBox = '';
		if ($evt['cbx']) {
			$chBox .= strpos($evt['chd'], $date) ? $evt['cmk'] : '&#x2610;';
			$chBox = "<span class='chkBox'>{$chBox}</span>";
		}
		if ($evtBody) {
			$popText = "<div class='fontS'><b>{$chBox}{$time} {$evt['tit']}</b>";
			$popText .= '<br>'.makeE($evt,$evtBody,'br',"<br>");
			$popText = htmlspecialchars(addslashes($popText.'</div>'));
			$popClass = ($evt['mde'] or $evt['r_t']) ? 'normal repeat' : 'normal';
			$popAttr = " onmouseover=\"pop(this,'{$popText}','{$popClass}',30)\"";
			$cursor = ' point';
		} else {
			$popAttr = '';
			$cursor = ' arrow';
		}
		$bgColor = $evt['cbg'] ? " style=\"background-color:{$evt['cbg']};\"" : '';
		if ($ef2Jump and preg_match('%https?://[^"\'\s]+%i',$evt['xf2'],$match)) {
			$onClick = " onclick=\"newWindow('{$match[0]}');\""; //jump to URL in extra field 2 
		} elseif ($evtWin) {
			$onClick = " onclick=\"".($evt['mayE'] ? 'editE' : 'showE')."({$evt['eid']},'{$date}','{$calID}');\""; //view or post/edit 
			$cursor = ' point';
		} else {
			$onClick = '';
		}
		echo "<div class='miniSquare{$cursor}'{$bgColor}{$onClick}{$popAttr}></div>\n";
	}
}

//sanity check
if (isset($_GET['oM']) and !preg_match('%^(-\d{1,2}|\d{0,2})$%', $_GET['oM'])) { exit('not permitted ('.substr(basename(__FILE__),0,-4).')'); } //invalid argument

error_reporting(E_ERROR); //errors only
//error_reporting(E_ALL); //errors, warnings and notices - test line

//get config data
if (file_exists('./lcconfig.php')) {
	require './lcconfig.php';
} else {
	exit('No config data!');
}

require './common/toolbox.php'; //load tools
require './common/toolboxd.php'; //database tools
require './common/retrieve.php'; //get retrieve function

if (empty($calID)) { $calID = $dbDef; } //select calendar

$dbH = dbConnect($calID); //connect to database

$set = getSettings(); //get settings from db

date_default_timezone_set($set['timeZone']); //set time zone

header("Cache-control: private"); //proxies: don't cache

require './lang/ui-'.strtolower($set['language']).'.php'; //set language

$stH = dbQuery("SELECT u.`ID`, g.`privs`, g.`vCatIDs` as vCats, g.`eCatIDs` as eCats FROM `users` AS u INNER JOIN `groups` AS g ON g.`ID` = u.`groupID` WHERE u.`ID` = 1");
$usr = $stH->fetch(PDO::FETCH_ASSOC); //user & group data
$stH = null; //release statement handle!

//compute dates
$offM = isset($_GET['oM']) ? $_GET['oM'] : 0; //offset Month
$timeD1 = mktime(12,0,0,date('n')+$offM,1,date('Y')); //time 1st day
$dateD1 = date("Y-m-d", $timeD1); //date 1st day
$curM = date("n",$timeD1);
$curY = date("Y",$timeD1);
$sOffset = ($set['weekStart']) ? date("N", $timeD1) - 1 : date("w", $timeD1); //offset first day
$eOffset = date("t", $timeD1) + $sOffset; //offset last day
$daysToShow = ($eOffset == 28) ? 28 : (($eOffset > 35) ? 42 : 35); //4, 5 or 6 weeks
$sDate = date("Y-m-d", $timeD1 - ($sOffset * 86400)); //start date in 1st week
$eDate = date("Y-m-d", $timeD1 + ($daysToShow - $sOffset - 1) * 86400); //end date in last week

//set filter
$usr['vCats'] = empty($cats) ? '0' : $cats; //categories to show
$usr['eCats'] = '0'; //all cat edit rights
$filter = ''; //init
if (!empty($groups)) { $filter .= " AND g.`ID` IN ({$groups})"; }
if (!empty($users)) { $filter .= " AND e.`userID` IN ({$users})"; }
if (!empty($venue)) { $filter .= " AND e.`venue` LIKE '%{$venue}%'"; }
if ($filter) { $filter = substr($filter,5); }

$evtList = array(); //init
retrieve($sDate,$eDate,'',$filter); //retrieve events

?>
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<title><?php echo $set['calendarTitle']; ?></title>
<meta name="description" content="LuxCal mini web calendar - a LuxSoft product">
<meta name="application-name" content="LuxCal V<?php echo LCV.' Display0 V'.$LDV?>">
<meta name="author" content="Roel Buining">
<meta name="robots" content="nofollow">
<link rel="canonical" href="<?php echo $set['calendarUrl']; ?>">
<style type="text/css">
<?php
echo "* {padding:0; margin:0;}
body, td, th {font:{$FFXXX};}
body {background:{$BXXXX}; color:{$CXXXX}; overflow:hidden;}
button {font-size:{$MBUTS}; padding:0px 2px; border-radius:2px; border:1px solid #666; cursor:pointer;}
a {color:{$CXXXX}; text-decoration:none; cursor:pointer;}
img {border-style:none;}
h6 {font-size:{$MDTHD};}

.fontS {font-size:{$MSMAL};}
.floatR {float:right;}
.floatL {float:left;}
.floatC {text-align:center;}
.point {cursor:pointer;}
.arrow {cursor:default;}
.hyper:hover {cursor:pointer; background:{$BGCTH};}

table.grid {width:100%; border-collapse:collapse;}
table.grid .dCol {border:1px solid {$EXXXX};}
table.grid tr.miniWeek {height:{$HDCEL}px;}
table.grid th {height:{$HWDAY}px; color:{$CBHAR}; background:{$BBHAR}; overflow:hidden;}
table.grid td {border:1px solid {$EXXXX}; vertical-align:top; overflow:hidden;}
table.grid td.we0 {background:{$BGWE1};}
table.grid td.wd0 {background:{$BGWD1};}
table.grid td.out {background:{$BGOUT};}
table.grid td.today {border:1px solid {$EGTOD}; background:{$BGTOD}}

.chkBox {color:{$CHLIT}; background:#FFFFFF; padding-right:2px;}
.chkBox:hover {background:{$BGCTH};}
.miniSquare {float:left; width:{$SQUAR}px; height:{$SQUAR}px; border:1px solid {$EXXXX};}
.dom {text-align:right; padding-right:2px;}

#htmlPop {position:absolute; width:150px; font-size:{$MPOPU}; padding:4px; border-radius:5px; box-shadow:5px 5px 5px #888; visibility:hidden; z-index:10;}
.normal {border:1px solid {$EHNOR}; background:{$BHNOR}}
.private {border:1px solid {$EHPRI}; background:{$BHPRI}}
.repeat {border:1px solid {$EHREP}; background:{$BHREP}}

.endBar {font-size:{$MSMAL}; color:{$CBHAR}; padding:0 8px;}
.footLB {font:italic 1.0em arial,sans-serif; color:#0055FF;}
.footLR {font:italic 1.0em arial,sans-serif; color:#AA0066;}
"
?>
</style>
<script src="common/toolbox.js"></script>
<script>
window.onload = function() {parent.setHeight(document.body.scrollHeight);}
function newWindow(url) { window.open(url, "_blank","toolbar=yes,scrollbars=yes,resizable=yes,top=200,left=300,width=800,height=600"); }
</script>
</head>

<body>
<?php
/* display header */
echo "<div class='floatC fontS'>{$xx['vws_click_for_full']}</div>\n";
echo "<form target='_blank' action='index.php' method='post'>\n";
echo "<input type='hidden' name='lcI' value='i'>
	<input type='hidden' name='cal' value='{$calID}'>
	<input type='hidden' name='cP' value='2'>
	<input type='hidden' name='cD' value='{$dateD1}'>\n";
$dateHdr = "<button type='submit' title=\"{$xx['vws_view_full']}\">".makeD($dateD1,3)."</button>\n";
$arrowL = "<a class='arrowLink' href='".htmlentities($_SERVER['PHP_SELF']).'?oM='.($offM-1)."' title='{$xx['vws_prev_month']}'>&#9664;</a>\n";
$arrowR = "<a class='arrowLink' href='".htmlentities($_SERVER['PHP_SELF']).'?oM='.($offM+1)."' title='{$xx['vws_next_month']}'>&#9654;</a>\n";
echo "<h6 class='floatC'>{$arrowL}&nbsp;&nbsp;&nbsp;{$dateHdr}&nbsp;&nbsp;&nbsp;{$arrowR}</h6>\n";
echo "</form>\n";

/* display month */
$days = $wkDays ? '1234567' : $set['workWeekDays']; //set days to show
$cWidth = round(98 / strlen($days),1).'%';
echo "<table class='grid'>
	<col span='".strlen($days)."' class='dCol' style='width:{$cWidth}'>
	<tr>\n";
for ($i = 0; $i < 7; $i++) {
	$cTime = mktime(12,0,0,$curM,$i-$sOffset+1,$curY ); //current time
	if (strpos($days,date("N",$cTime)) !== false) { echo "<th>{$wkDays_s[$set['weekStart'] + $i]}</th>"; } //week days
}
echo "</tr>\n";
for ($i = 0; $i < $daysToShow; $i++) {
	$cTime = mktime(12,0,0,$curM,$i-$sOffset+1,$curY ); //current time
	$cDate = date("Y-m-d", $cTime);
	if ($i%7 == 0) { //new week
		echo "<tr class='miniWeek'>\n";
	}
	$dayNr = date("N", $cTime);
	if (strpos($days,$dayNr) !== false) {
		$dow = ($i < $sOffset or $i >= $eOffset) ? 'out' : (($dayNr > 5) ? 'we0' : 'wd0');
		if ($cDate == date("Y-m-d")) { $dow .= ' today'; }
		$day = ltrim(substr($cDate, 8, 2),"0");
		$dHead = ($evtWin and $usr['privs'] > 1) ? "class='dom hyper' onclick=\"newE('{$cDate}',0);\" title=\"{$xx['vws_add_event']}\"" : "class='dom'";
		echo "<td class='{$dow}'>\n<div {$dHead}>{$day}</div>\n";
			if (!empty($evtList[$cDate])) { showEvents($cDate); }
		echo "</td>\n";
	}
	if ($i%7 == 6) { echo "</tr>\n"; } //if last day of week, wrap to left
}
echo "<tr>\n<th colspan='7' class='endBar'>
	<span class='floatL'><a href='rssfeed.php' title='RSS feeds' target='_blank' >RSS</a></span>
	<span class='floatR'><a href='http://www.luxsoft.eu' target='_blank'><span class='footLB'>Lux</span><span class='footLR'>Soft</span></a></span>\n";
if ($offM != 0) { echo "<a class='floatC' href='".htmlentities($_SERVER['PHP_SELF'])."?oM=0' title=\"{$xx['vws_back_to_today']}\">{$xx['vws_today']}</a>\n"; }
?>
</th>
</tr>
</table>
</body>
</html>
