<?php
/*
 = General functions used by Week and Day view scripts =

 Copyright 2009-2018 LuxSoft - www.LuxSoft.eu

This file is part of the LuxCal Web Calendar.

The LuxCal Web Calendar is free software: you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by the Free Software Foundation, 
either version 3 of the License, or (at your option) any later version.

The LuxCal Web Calendar is distributed in the hope that it will be useful, but WITHOUT 
ANY WARRANTY. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with the LuxCal 
Web Calendar. If not, see: http://www.gnu.org/licenses/.
*/

//sanity check
if (empty($lcV)) { exit('not permitted ('.substr(basename(__FILE__),0,-4).')'); } //launch via script only

function showEvents($date) {
	global $usr, $evtList, $set, $isMob, $eDetails;

	$thsM = ($set['dwStartHour'] * 60); //threshold start of day in mins
	$theM = ($set['dwEndHour'] * 60); //threshold end of day in mins
	$offset = $set['dwStartHour'] ? 2 * $set['dwTimeSlot'] : $set['dwTimeSlot']; //"earlier" row
	//hereafter: M = in nbr of mins
	foreach ($evtList[$date] as $eIx => $evt) {
		if ($evt['mde']) { //multi-day-event
			if ($evt['mde'] != 1) { $evt['sti'] = '00:00'; }
			if ($evt['mde'] != 3) { $evt['eti'] = '23:59'; }
		}
		if (($evt['sti'] == '' and $evt['eti'] == '') or $evt['ald']) { //all day (takes up 1 slot at the top)
			$st[] = 0; //start time
			$et[] = $set['dwTimeSlot']; //end time
		} else {
			$stM = substr($evt['sti'],0,2) * 60 + intval(substr($evt['sti'],3,2)); //start time
			if ($stM < $thsM) {
				$st[] = $set['dwTimeSlot']; //start time < threshold start of day in mins
			} elseif ($stM < $theM) {
				$st[] = $stM - $thsM + $offset; //start time < threshold end of day in mins
			} else {
				$st[] = $theM - $thsM + $offset; //start time >= threshold end of day in mins
			}
			if ($evt['eti'] == "" or $evt['eti'] == $evt['sti']) {
				$et[] = end($st) + $set['dwTimeSlot'];
			} else {
				$etM = substr($evt['eti'],0,2) * 60 + intval(substr($evt['eti'],3,2)); //end time
				if ($etM <= $thsM) {
					$et[] = $offset; //end time <= threshold start of day in mins
				} elseif ($etM <= $theM) {
					$et[] = $etM - $thsM + $offset; //end time < threshold end of day in mins
				} else {
					$et[] = $theM - $thsM + $offset + $set['dwTimeSlot']; //end time > threshold end of day in mins
				}
			}
		}
	}
	//for day $date we now have :
	//$st: array with start time in mins for each event
	//$et: array with end time in mins for each event
	//the indexes in these arrays correspond to the indexes in $evtList
	$sEmpty[0][0] = 0;
	$eEmpty[0][0] = 1440; //24 x 60 mins
	$indent = 0;
	$column = array(); //array with column numbers of each event
	foreach ($st as $i => $stM) { //i: index in $evtList, stM: start time in mins
		$found = false;
		foreach ($sEmpty as $k => $v) {
			foreach ($v as $kk => $sEtM) {
				if ($stM >= $sEtM and $et[$i] <= $eEmpty[$k][$kk]) {
					$sEmpty[$k][] = $et[$i]; //end time in mins
					$eEmpty[$k][] = $eEmpty[$k][$kk];
					$eEmpty[$k][$kk] = $stM; //start in mins
					$sFill[$k][] = $stM;
					$evIx[$k][] = $i;
					$column[$i] = $k;
					$found = true;
					break 2;
				}
			}
		}
		if (!$found) {
			$indent++;
			$sEmpty[$indent][0] = 0;
			$eEmpty[$indent][0] = $stM;
			$sEmpty[$indent][1] = $et[$i];
			$eEmpty[$indent][1] = 1440; //24 x 60
			$sFill[$indent][0] = $stM;
			$evIx[$indent][0] = $i;
			$column[$i] = $indent;
		}
	}
	$cWidth = round(90 / ($indent+1),1); //width of smallest column
	foreach ($sFill as $k => $v) { //1 min = 1px
		$eLeft = ($cWidth + 0.5) * $k; //event left side in %
		$eWidth = $cWidth - 0.5; //event width in %
		foreach ($v as $kk => $stM) { //event start time in mins
			$etM = $sEmpty[$k][$kk + 1]; //event end time in mins
			$eHeight = $etM - $stM; //event height in mins
			$stM = round($stM * $set['dwTsHeight'] / $set['dwTimeSlot']) - 1; //scale start time in px
			$eHeight = round($eHeight * $set['dwTsHeight'] / $set['dwTimeSlot']) - 1; //scale height in px
			$i = $evIx[$k][$kk];
			$evt = &$evtList[$date][$i];
			$sti = ($evt['sti']) ? ITtoDT($evt['sti']) : '';
			$stiPrefix = (substr($evt['sti'],0,2) < $set['dwStartHour'] or substr($evt['sti'],0,2) >= $set['dwEndHour']) ? $sti.' ' : '';
			$time = makeHovT($evt);
			$chBox = '';
			if ($evt['cbx']) {
				$mayCheck = ($usr['privs'] > 3 or ($usr['privs'] > 1 and $evt['uid'] == $usr['ID'])); //boolean
				$chBox .= strpos($evt['chd'], $date) ? $evt['cmk'] : '&#x2610;';
				$cBoxAtt = $mayCheck ? "class='chkBox floatL point' onclick=\"checkE(this,{$evt['eid']},'{$date}');\"" : "class='chkBox floatL arrow'";
				$chBox = "<span title='{$evt['clb']}' {$cBoxAtt}>{$chBox}</span>";
			}
			if ($set['evtTemplPop']) {
				$popText = "<b>{$time} {$evt['tix']}</b><br>";
				if ($eDetails or $evt['mayE']) {
					$popText .= makeE($evt,$set['evtTemplPop'],'br','<br>');
				}
				$popText = htmlspecialchars(addslashes($popText));
				$popClass = ($evt['pri'] ? 'private' : 'normal').(($evt['mde'] or $evt['r_t']) ? ' repeat' : '');
				$popAttr = " onmouseover=\"pop(this,'{$popText}','{$popClass}')\"";
			} else {
				$popAttr = '';
			}
			if ($set['eventColor']) { //use event color
				$eStyle = ($evt['cco'] ? "color:{$evt['cco']};" : '').' background-color:'.($evt['cbg'] ? $evt['cbg'] : '#FFFFFF').';';
			} else { //use user color
				$eStyle = ' background-color:'.($evt['uco'] ? $evt['uco'] : '#FFFFFF').';';
			}
			if ($evt['app'] and !$evt['apd']) { $eStyle .= 'border-left:2px solid #ff0000;'; }
			$class = $eHeight < 21 ? 'dwEventNw' : 'dwEvent';
			// enlarge box if possible 
			// 1. find next column of overlapping event starting before
			$ovlColumn = $indent+1; 
			for ($iTest=0;$iTest<$i;$iTest++) {
				$evtBefore = &$evtList[$date][$iTest];
				if ($evtBefore['eti'] > $evt['sti'] && $column[$iTest] > $column[$i] && $column[$iTest] < $ovlColumn) {
					$ovlColumn = $column[$iTest];
				}
			}
			// 2. find next column of overlapping event starting later
			for ($iTest=$i+1;$iTest<count($st);$iTest++) {
				$evtAfter = &$evtList[$date][$iTest];
				if ($evtAfter['sti'] < $evt['eti'] && $column[$iTest] > $column[$i] && $column[$iTest] < $ovlColumn) {
					$ovlColumn = $column[$iTest];
				}
			}
			$eWidthAdjusted = ($ovlColumn-$k) * $cWidth - 0.5;
//			echo "<div class='evtBox' style='top:{$stM}px; left:{$eLeft}%; height:{$eHeight}px; width:{$eWidth}%;{$eStyle}'>\n";
			echo "<div class='evtBox evtTitle' style='top:{$stM}px; left:{$eLeft}%; height:{$eHeight}px; width:{$eWidthAdjusted}%;{$eStyle}'>\n";

			if (!$isMob) {
				$click = ($evt['mayE'] ? 'editE' : 'showE')."({$evt['eid']},'{$date}')";
				$onClick = ($eDetails or $evt['mayE']) ? "<span class='point' onclick=\"{$click};\"" : "<span class='arrow'";
				echo "<div class='{$class}'>{$chBox}{$onClick}{$popAttr}>{$stiPrefix}{$evt['tix']}</span></div></div>\n";
			} else {
				echo "<div class='{$class}'>{$chBox}".(($eDetails or $evt['mayE']) ? "<span class='point' " : "<span class='arrow'")."{$popAttr}>{$stiPrefix}{$evt['tix']}</span></div></div>\n";
			}
		}
	}
}

function showHours() {
	global $set, $xx;
	//build day
	$tsHeight = $set['dwTsHeight'] -1;
	echo "<div class='timeFrame'>\n";
	echo "<div class='times' style='height:{$tsHeight}px;'>{$xx['vws_all_day']}</div>\n";
	$i = $set['dwStartHour'];
	$j = 0;
	if ($set['dwStartHour']) {
		echo "<div class='times' style='height:{$tsHeight}px;'>{$xx['vws_earlier']}</div>\n";
	}
	while ($i < $set['dwEndHour']) {
		echo "<div class='times' style='height:{$tsHeight}px;'>".ITtoDT(str_pad($i,2,"0",STR_PAD_LEFT).":".str_pad($j,2,"0",STR_PAD_LEFT))."</div>\n";
		if (($j += $set['dwTimeSlot']) >= 60) {
			$i++;
			$j -= 60;
		}
	}
	if ($set['dwEndHour'] < 24) {
		echo "<div class='times' style='height:{$tsHeight}px;'>{$xx['vws_later']}</div>\n";
	}
	echo "</div>\n";
}

function showDay($cDate,$caption="") {
	global $set, $evtList;

	//build day
	$tsHeight = $set['dwTsHeight'] -1;
	echo "<div class='timeFrame'>\n";
	echo "<var style='height:{$tsHeight}px;' id='a00:00:{$cDate}'></var>\n";
	$i = $set['dwStartHour'];
	$j = 0;
	if ($set['dwStartHour']) {
		echo "<var style='height:{$tsHeight}px;' id='t00:30:{$cDate}'></var>\n";
	}
	while ($i < $set['dwEndHour']) {
		echo "<var style='height:{$tsHeight}px;' id='t".str_pad($i,2,"0",STR_PAD_LEFT).":".str_pad($j,2,"0",STR_PAD_LEFT).":{$cDate}'></var>\n";
		if (($j += $set['dwTimeSlot']) >= 60) {
			$i++;
			$j -= 60;
		}
	}
	if ($set['dwEndHour'] < 24) {
		echo "<var style='height:{$tsHeight}px;' id='t".str_pad($i,2,"0",STR_PAD_LEFT).":".str_pad($j,2,"0",STR_PAD_LEFT).":{$cDate}'></var>\n";
	}
	echo "<div class=dates>\n";
	if (!empty($evtList[$cDate])) { showEvents($cDate); }
	echo "</div>";
	echo "</div>\n";
}


if ($usr['privs'] > 1) {
?>
<script>
//drag time functions
window.onload = dragTime;
var start, end, color, draggedEls=[];

function dragTime() {
	var x = [];
	x = $T("var");
	color = x[0].style.backgroundColor;
	for (var i = (x.length - 1);i >= 0;i--) {
		x[i].onmousedown = starttime;
		x[i].onmouseover = dragtime;
		x[i].onmouseup = endtime;
	}
}

function starttime() {
	start = end = this.id;
	this.style.backgroundColor = "#cccccc";
	draggedEls.push(this); //remember colored elements
}

function dragtime() {
	if (start) {
		if (this.id < end) {
			$I(end).style.backgroundColor=color;
		} else {
			this.style.backgroundColor = "#cccccc";
			draggedEls.push(this); //remember colored elements
		}
		end = this.id;
	}
}

function endtime() {
	var hrs,mins,win,sdate,stime,etime;
	var x = [];
	if (end >= start) {
		sdate = start.substr(7);
		stime = start.substr(1,2) + ":" + start.substr(4,2);
		hrs = parseInt(end.substr(1,2),10);
		mins = parseInt(end.substr(4,2),10) + dwTimeSlot;
		if (mins >= 60) { hrs++; mins = mins - 60; }
		if (hrs == 24) { hrs--; mins = 59; }
		etime = String("0" + hrs).slice(-2) + ":" + String("0" + mins).slice(-2);
		if (start.substr(0,1) == 'a') { etime ="23:59"; } //all day
		win = newE(sdate,cid,stime,etime);
		for (var i = (draggedEls.length - 1);i >= 0;i--) {
			draggedEls[i].style.backgroundColor = color;
		}
	}
	start = end = null;
}
</script>
<?php
}
?>
